==> ejc-businessplan-impl-3.0.0-20220225.080726-13-sources.jar: com/ejianc/business/change/vo/ChangesubpackageVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包分供管理策划变更
 * 
 * @author generator
 * 
 */
public class ChangesubpackageVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long subpackageId; // 分包分供管理策划id
    private java.lang.String billCode; // 单据编码
    private java.lang.String agentName; // 经办人
    private java.lang.Long agentId; // 经办人id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.util.Date effectTime; // 生效时间
    private java.lang.String changeReason; // 变更原因
    
    private List<ChangesubpackagedetaillVO> changesubpackagedetaillVos = new ArrayList<>(); // 分包管理策划变更子表
    private List<ChangesubpackagesupplydetailVO> changesubpackagesupplydetailVos = new ArrayList<>(); // 分供管理策划变更子表

    /**
     * 分包分供管理策划id
     */
    public java.lang.Long getSubpackageId() {
        return subpackageId;
    }

    /**
     * 分包分供管理策划id
     */
    public void setSubpackageId(java.lang.Long subpackageId) {
        this.subpackageId = subpackageId;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 经办人
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectTime() {
        return effectTime;
    }

    /**
     * 生效时间
     */
    public void setEffectTime(java.util.Date effectTime) {
        this.effectTime = effectTime;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    
     /**
      * 分包管理策划变更子表
      */
     public List<ChangesubpackagedetaillVO> getChangesubpackagedetaillVos() {
        return changesubpackagedetaillVos;
     }

     /**
      * 分包管理策划变更子表
      */
     public void setChangesubpackagedetaillVos(List<ChangesubpackagedetaillVO> changesubpackagedetaillVos) {
        this.changesubpackagedetaillVos = changesubpackagedetaillVos;
     }
     /**
      * 分供管理策划变更子表
      */
     public List<ChangesubpackagesupplydetailVO> getChangesubpackagesupplydetailVos() {
        return changesubpackagesupplydetailVos;
     }

     /**
      * 分供管理策划变更子表
      */
     public void setChangesubpackagesupplydetailVos(List<ChangesubpackagesupplydetailVO> changesubpackagesupplydetailVos) {
        this.changesubpackagesupplydetailVos = changesubpackagesupplydetailVos;
     }
}

==> ejc-businessplan-impl-3.0.0-20220321.111257-20-sources.jar: com/ejianc/business/change/vo/ChangesubpackageVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordsubpackageVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包分供管理策划变更
 * 
 * @author generator
 * 
 */
public class ChangesubpackageVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long subpackageId; // 分包分供管理策划id
    private java.lang.String billCode; // 单据编码
    private java.lang.String agentName; // 经办人
    private java.lang.Long agentId; // 经办人id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.util.Date effectTime; // 生效时间
    private java.lang.String changeReason; // 变更原因
    
    private List<ChangesubpackagedetaillVO> subpackagepackgedetailEntities = new ArrayList<>(); // 分包管理策划变更子表
    private List<ChangesubpackagesupplydetailVO> subpackagesupplydetailEntities = new ArrayList<>(); // 分供管理策划变更子表
    private List<RecordsubpackageVO> recordsubpackageList = new ArrayList<>(); //变更记录历史信息

    /**
     * 分包分供管理策划id
     */
    public java.lang.Long getSubpackageId() {
        return subpackageId;
    }

    /**
     * 分包分供管理策划id
     */
    public void setSubpackageId(java.lang.Long subpackageId) {
        this.subpackageId = subpackageId;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 经办人
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectTime() {
        return effectTime;
    }

    /**
     * 生效时间
     */
    public void setEffectTime(java.util.Date effectTime) {
        this.effectTime = effectTime;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    
     /**
      * 分包管理策划变更子表
      */
    public List<ChangesubpackagedetaillVO> getSubpackagepackgedetailEntities() {
        return subpackagepackgedetailEntities;
    }

    /**
     * 分包管理策划变更子表
     */
    public void setSubpackagepackgedetailEntities(List<ChangesubpackagedetaillVO> subpackagepackgedetailEntities) {
        this.subpackagepackgedetailEntities = subpackagepackgedetailEntities;
    }


     /**
      * 分供管理策划变更子表
      */
    public List<ChangesubpackagesupplydetailVO> getSubpackagesupplydetailEntities() {
        return subpackagesupplydetailEntities;
    }

    /**
     * 分供管理策划变更子表
     */
    public void setSubpackagesupplydetailEntities(List<ChangesubpackagesupplydetailVO> subpackagesupplydetailEntities) {
        this.subpackagesupplydetailEntities = subpackagesupplydetailEntities;
    }

    public List<RecordsubpackageVO> getRecordsubpackageList() {
        return recordsubpackageList;
    }

    public void setRecordsubpackageList(List<RecordsubpackageVO> recordsubpackageList) {
        this.recordsubpackageList = recordsubpackageList;
    }
}
